IMFApplePayButton class abstract

Implementers

Constructors

IMFApplePayButton()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applePayPayment(MFExecutePaymentRequest request, String lang, dynamic onInvoiceCreated(String invoiceId)) → Future<MFGetPaymentStatusResponse>
displayApplePayButton(MFInitiateSessionResponse session, MFExecutePaymentRequest request, String lang) → Future<MFCallbackResponse>
executeApplePayButton(MFExecutePaymentRequest? request, dynamic onInvoiceCreated(String invoiceId)) → Future<MFGetPaymentStatusResponse>
load(MFInitiateSessionResponse session, MFExecutePaymentRequest request, String lang, [dynamic onSessionCreated(String message)?]) → Future<MFGetPaymentStatusResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited