MFButtonType class

Constructors

MFButtonType()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

BOOK → const int
BUY → const int
CHECKOUT → const int
ORDER → const int
PAY → const int
PLAIN → const int
SUBSCRIBE → const int