MFGPayFlutter class

Constructors

MFGPayFlutter({BinaryMessenger? binaryMessenger})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCurrentSetup() → void
Clear the current Google Pay setup and clean up resources Call this when switching between payment modes to prevent callback leaks
dispose() → void
executeGooglePayPayment(MFExecutePaymentRequest executePaymentRequest, String lang, dynamic onInvoiceCreated(String invoiceId)?) → Future<MFGetPaymentStatusResponse>
isGooglePayAvailable() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openGooglePaySheet() → Future<String>
setupGooglePayLauncherAuto(String sessionId, MFGooglePayRequest googlePayRequest, dynamic onInvoiceCreated(String invoiceId)?, dynamic onExecutePaymentSuccess(String, MFGetPaymentStatusResponse)?, dynamic onError(MFError)?) → Future<String>
setupGooglePayLauncherManual(String sessionId, MFGooglePayRequest googlePayRequest, dynamic onSessionUpdated(String invoiceId)?, dynamic onError(MFError)?) → Future<String>
setupGooglePayLauncherTokenOnly(MFGooglePayRequest googlePayRequest, dynamic onReceivedToken(String invoiceId)?, dynamic onError(MFError)?) → Future<String>
toString() → String
A string representation of this object.
inherited
updateBinaryMessenger(BinaryMessenger? binaryMessenger) → void
updateGooglePayRequestAmount(String amount) → Future<String>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

codec → const MessageCodec<Object?>
paymentExecutionTimeout → const Duration
Timeout duration for payment execution operations
paymentSetupTimeout → const Duration
Timeout duration for payment setup operations
quickOperationTimeout → const Duration
Timeout duration for quick operations (availability, updates, etc.)