setupTokenOnly abstract method

Future<String> setupTokenOnly(
  1. MFGooglePayRequest googlePayRequest, {
  2. dynamic onReceivedToken(
    1. String token
    )?,
  3. dynamic onError(
    1. MFError
    )?,
})

Setup Google Pay with TokenOnly mode using MFGooglePayLauncher

This mode gets a Google Pay token without executing payment. Use this to save tokens for future recurring payments.

Callbacks:

  • onReceivedToken: Called when Google Pay token is successfully received
  • onError: Called if an error occurs during token generation

Returns the token after setup completes

Implementation

Future<String> setupTokenOnly(MFGooglePayRequest googlePayRequest,
    {Function(String token)? onReceivedToken, Function(MFError)? onError});