MFGooglePayButton class

Inheritance
Implemented types

Constructors

MFGooglePayButton({Key? key, MFGooglePayButtonConfig config = MFGooglePayButtonConfig.defaultConfig})
const

Properties

config → MFGooglePayButtonConfig
Button appearance configuration
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MFGooglePayButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
executePayment(MFExecutePaymentRequest executePaymentRequest, String lang, {dynamic onInvoiceCreated(String invoiceId)?}) → Future<MFGetPaymentStatusResponse>
Execute payment manually (for Manual mode)
override
isGooglePayAvailable() → Future<bool>
Check if Google Pay is available
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openGooglePaySheet() → Future<String>
Manually open the Google Pay payment sheet
override
setupGooglePayHelper(String sessionId, MFGooglePayRequest googlePayRequest, dynamic onInvoiceCreated(String invoiceId)) → Future<MFGetPaymentStatusResponse>
@deprecated Use setupWithAutoExecute (for auto execute payment) or setupWithManualExecute (for manual execute payment) instead. This method uses deprecated MFGooglePayHelper.
override
setupGooglePayTokenHelper(MFGooglePayRequest googlePayRequest) → Future<String>
@deprecated Use setupTokenOnly instead. This method uses deprecated MFGooglePayTokenHelper.
override
setupTokenOnly(MFGooglePayRequest googlePayRequest, {dynamic onReceivedToken(String invoiceId)?, dynamic onError(MFError)?}) → Future<String>
Setup Google Pay with TokenOnly mode using MFGooglePayLauncher
override
setupWithAutoExecute(String sessionId, MFGooglePayRequest googlePayRequest, {dynamic onInvoiceCreated(String invoiceId)?, dynamic onExecutePaymentSuccess(String, MFGetPaymentStatusResponse)?, dynamic onError(MFError)?}) → Future<String>
Setup Google Pay with Auto execution mode using MFGooglePayLauncher
override
setupWithManualExecute(String sessionId, MFGooglePayRequest googlePayRequest, {dynamic onSessionUpdated(String invoiceId)?, dynamic onError(MFError)?}) → Future<String>
Setup Google Pay with Manual execution mode using MFGooglePayLauncher
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateRequestAmount(String amount) → Future<String>
Update the request amount for dynamic pricing
override
validateConfig(MFGooglePayButtonConfig config) → void
Validate button configuration
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited