MFGooglePayButtonConfig class

Configuration options for MFGooglePayButton appearance and behavior

Based on native Android MFGooglePayButton properties. See: https://developers.google.com/pay/api/android/guides/brand-guidelines

Example:

MFGooglePayButton(
  config: MFGooglePayButtonConfig(
    buttonType: MFButtonType.BUY,
    buttonTheme: MFButtonTheme.LIGHT,
    cornerRadius: 20,
  ),
)

Constructors

MFGooglePayButtonConfig({int buttonType = MFButtonType.PAY, int buttonTheme = MFButtonTheme.DARK, int cornerRadius = 10})
const

Properties

buttonTheme → int
Button theme: Visual appearance of the button
final
buttonType → int
Button type: Determines the text and behavior of the button
final
cornerRadius → int
Corner radius in pixels Controls how rounded the button corners appear
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? buttonType, int? buttonTheme, int? cornerRadius}) → MFGooglePayButtonConfig
Copy with method for creating modified configs
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Convert to map for platform channel
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

defaultConfig → const MFGooglePayButtonConfig
Default configuration