cornerRadius property
Corner radius in pixels Controls how rounded the button corners appear
Defaults to 10
Implementation
final int cornerRadius;
Corner radius in pixels Controls how rounded the button corners appear
Defaults to 10
final int cornerRadius;