MFCard class

Constructors

MFCard({required String? cardHolderName, required String? number, required String? expiryMonth, required String? expiryYear, required String? securityCode})
MFCard.fromJson(Map<String, dynamic> json)

Properties

cardHolderName ↔ String?
getter/setter pair
expiryMonth ↔ String?
getter/setter pair
expiryYear ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
number ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityCode ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited