MFCardViewInput class

Constructors

MFCardViewInput()
MFCardViewInput.fromJson(Map<String, dynamic> json)

Properties

borderColor ↔ num?
getter/setter pair
borderRadius ↔ num?
getter/setter pair
borderWidth ↔ num?
getter/setter pair
boxShadow ↔ MFBoxShadow?
getter/setter pair
color ↔ num?
getter/setter pair
fontFamily ↔ String?
getter/setter pair
fontSize ↔ num?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputHeight ↔ num?
getter/setter pair
inputMargin ↔ num?
getter/setter pair
placeHolder ↔ MFCardViewPlaceHolder?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited