MFCardViewStyle class

Constructors

MFCardViewStyle()
MFCardViewStyle.fromJson(Map<String, dynamic> json)

Properties

backgroundColor ↔ num
getter/setter pair
cardHeight ↔ int
getter/setter pair
direction ↔ String
getter/setter pair
error ↔ MFCardViewError?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideCardIcons ↔ bool
getter/setter pair
input ↔ MFCardViewInput?
getter/setter pair
label ↔ MFCardViewLabel?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedCardText ↔ MFSavedCardText?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited