MFDeleteAlert class

Constructors

MFDeleteAlert({String? title, String? message, String? confirm, String? cancel})
MFDeleteAlert.fromJson(Map<String, dynamic> json)
factory

Properties

cancel ↔ String?
getter/setter pair
confirm ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited