MFExecutePaymentResponse class

Constructors

MFExecutePaymentResponse({int? invoiceId, bool? isDirectPayment, String? paymentURL, String? customerReference, String? userDefinedField, String? recurringId})
MFExecutePaymentResponse.fromJson(Map<String, dynamic> json)

Properties

customerReference ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invoiceId ↔ int?
getter/setter pair
isDirectPayment ↔ bool?
getter/setter pair
paymentURL ↔ String?
getter/setter pair
recurringId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userDefinedField ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited