MFGetPaymentStatusResponse class

Constructors

MFGetPaymentStatusResponse({int? invoiceId, String? invoiceStatus, String? invoiceReference, String? customerReference, String? createdDate, String? expiryDate, String? expiryTime, num? invoiceValue, String? comments, String? customerName, String? customerMobile, String? customerEmail, String? userDefinedField, String? invoiceDisplayValue, num? dueDeposit, String? depositStatus, String? recurringId, List<MFInvoiceItem>? invoiceItems, List<MFInvoiceTransaction>? invoiceTransactions, List<MFSupplier>? suppliers})
MFGetPaymentStatusResponse.fromJson(Map<String, dynamic> json)

Properties

comments ↔ String?
getter/setter pair
createdDate ↔ String?
getter/setter pair
customerEmail ↔ String?
getter/setter pair
customerMobile ↔ String?
getter/setter pair
customerName ↔ String?
getter/setter pair
customerReference ↔ String?
getter/setter pair
depositStatus ↔ String?
getter/setter pair
dueDeposit ↔ num?
getter/setter pair
expiryDate ↔ String?
getter/setter pair
expiryTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invoiceDisplayValue ↔ String?
getter/setter pair
invoiceId ↔ int?
getter/setter pair
invoiceItems ↔ List<MFInvoiceItem>?
getter/setter pair
invoiceReference ↔ String?
getter/setter pair
invoiceStatus ↔ String?
getter/setter pair
invoiceTransactions ↔ List<MFInvoiceTransaction>?
getter/setter pair
invoiceValue ↔ num?
getter/setter pair
recurringId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suppliers ↔ List<MFSupplier>?
getter/setter pair
userDefinedField ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited