MFGooglePayRequest class

Constructors

MFGooglePayRequest({required String? totalPrice, required String? merchantId, required String? merchantName, required String? countryCode, required String? currencyIso})

Properties

countryCode ↔ String?
getter/setter pair
currencyIso ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantId ↔ String?
getter/setter pair
merchantName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalPrice ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited