MFInvoiceItem class

Constructors

MFInvoiceItem({String? itemName, int? quantity, num? unitPrice, int? weight, int? width, int? height, int? depth})
MFInvoiceItem.fromJson(Map<String, dynamic> json)

Properties

depth ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
getter/setter pair
itemName ↔ String?
getter/setter pair
quantity ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitPrice ↔ num?
getter/setter pair
weight ↔ int?
getter/setter pair
width ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited