MFInvoiceTransaction class

Constructors

MFInvoiceTransaction({String? transactionDate, String? paymentGateway, String? referenceId, String? trackId, String? transactionId, String? paymentId, String? authorizationId, String? transactionStatus, String? transationValue, String? customerServiceCharge, String? totalServiceCharge, String? dueValue, String? paidCurrency, String? paidCurrencyValue, String? ipAddress, String? country, String? currency, String? error, String? cardNumber, String? errorCode})
MFInvoiceTransaction.fromJson(Map<String, dynamic> json)

Properties

authorizationId ↔ String?
getter/setter pair
cardNumber ↔ String?
getter/setter pair
country ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
customerServiceCharge ↔ String?
getter/setter pair
dueValue ↔ String?
getter/setter pair
error ↔ String?
getter/setter pair
errorCode ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String?
getter/setter pair
paidCurrency ↔ String?
getter/setter pair
paidCurrencyValue ↔ String?
getter/setter pair
paymentGateway ↔ String?
getter/setter pair
paymentId ↔ String?
getter/setter pair
referenceId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalServiceCharge ↔ String?
getter/setter pair
trackId ↔ String?
getter/setter pair
transactionDate ↔ String?
getter/setter pair
transactionId ↔ String?
getter/setter pair
transactionStatus ↔ String?
getter/setter pair
transationValue ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited