MFRecurringInvoice class

Constructors

MFRecurringInvoice({int? invoiceId, String? customerReference, String? customerName, String? customerMobile, String? createdDate, String? invoiceStatus})
MFRecurringInvoice.fromJson(Map<String, dynamic> json)

Properties

createdDate ↔ String?
getter/setter pair
customerMobile ↔ String?
getter/setter pair
customerName ↔ String?
getter/setter pair
customerReference ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invoiceId ↔ int?
getter/setter pair
invoiceStatus ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited