MFRecurringPayment class

Constructors

MFRecurringPayment({String? recurringId, String? recurringStatus, String? creationDate, int? recurringValue, String? recurringType, int? intervalDays, int? executedTimes, String? lastPayDate, String? nextPayDate, bool? isActive, List<MFRecurringInvoice>? recurringInvoices})
MFRecurringPayment.fromJson(Map<String, dynamic> json)

Properties

creationDate ↔ String?
getter/setter pair
executedTimes ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intervalDays ↔ int?
getter/setter pair
isActive ↔ bool?
getter/setter pair
lastPayDate ↔ String?
getter/setter pair
nextPayDate ↔ String?
getter/setter pair
recurringId ↔ String?
getter/setter pair
recurringInvoices ↔ List<MFRecurringInvoice>?
getter/setter pair
recurringStatus ↔ String?
getter/setter pair
recurringType ↔ String?
getter/setter pair
recurringValue ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited