ChannelGPayName class
Constructors
Properties
- googlePayAvailable → String
-
final
- googlePayExecutePayment → String
-
final
- googlePayLauncherAuto → String
-
final
- googlePayLauncherManual → String
-
final
- googlePayLauncherTokenOnly → String
-
final
- googlePayOpenSheet → String
-
final
- googlePayUpdateAmount → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited