IMFGooglePayButton class abstract

Implementers

Constructors

IMFGooglePayButton()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executePayment(MFExecutePaymentRequest executePaymentRequest, String lang, {dynamic onInvoiceCreated(String invoiceId)?}) Future<MFGetPaymentStatusResponse>
Execute payment manually (for Manual mode)
isGooglePayAvailable() Future<bool>
Check if Google Pay is available
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openGooglePaySheet() Future<String>
Manually open the Google Pay payment sheet
setupGooglePayHelper(String sessionId, MFGooglePayRequest googlePayRequest, dynamic onInvoiceCreated(String invoiceId)) Future<MFGetPaymentStatusResponse>
@deprecated Use setupWithLauncher instead. This method uses deprecated MFGooglePayHelper.
setupGooglePayTokenHelper(MFGooglePayRequest googlePayRequest) Future<String>
@deprecated Use setupWithLauncher instead. This method uses deprecated MFGooglePayTokenHelper.
setupTokenOnly(MFGooglePayRequest googlePayRequest, {dynamic onReceivedToken(String token)?, dynamic onError(MFError)?}) Future<String>
Setup Google Pay with TokenOnly mode using MFGooglePayLauncher
setupWithAutoExecute(String sessionId, MFGooglePayRequest googlePayRequest, {dynamic onInvoiceCreated(String invoiceId)?, dynamic onExecutePaymentSuccess(String, MFGetPaymentStatusResponse)?, dynamic onError(MFError)?}) Future<String>
Setup Google Pay with Auto execution mode using MFGooglePayLauncher
setupWithManualExecute(String sessionId, MFGooglePayRequest googlePayRequest, {dynamic onSessionUpdated(String sessionId)?, dynamic onError(MFError)?}) Future<String>
Setup Google Pay with Manual execution mode using MFGooglePayLauncher
toString() String
A string representation of this object.
inherited
updateRequestAmount(String amount) Future<String>
Update the request amount for dynamic pricing

Operators

operator ==(Object other) bool
The equality operator.
inherited