setupTokenOnly abstract method
Future<String>
setupTokenOnly(
- MFGooglePayRequest googlePayRequest, {
- dynamic onReceivedToken(
- String token
- dynamic onError()?,
Setup Google Pay with TokenOnly mode using MFGooglePayLauncher
This mode gets a Google Pay token without executing payment. Use this to save tokens for future recurring payments.
Callbacks:
onReceivedToken: Called when Google Pay token is successfully receivedonError: Called if an error occurs during token generation
Returns the token after setup completes
Implementation
Future<String> setupTokenOnly(MFGooglePayRequest googlePayRequest,
{Function(String token)? onReceivedToken, Function(MFError)? onError});