setupWithAutoExecute abstract method
Future<String>
setupWithAutoExecute(
- String sessionId,
- MFGooglePayRequest googlePayRequest, {
- dynamic onInvoiceCreated(
- String invoiceId
- dynamic onExecutePaymentSuccess()?,
- dynamic onError()?,
Setup Google Pay with Auto execution mode using MFGooglePayLauncher
This mode automatically executes payment after getting the Google Pay token. Use this for simple one-time payments where you want automatic execution.
Callbacks:
onInvoiceCreated: Called when invoice is created (before payment execution)onExecutePaymentSuccess: Called when payment is executed successfully with invoice ID and payment statusonError: Called if an error occurs during the payment process
Returns setup status after configuration completes
Implementation
Future<String> setupWithAutoExecute(
String sessionId, MFGooglePayRequest googlePayRequest,
{Function(String invoiceId)? onInvoiceCreated,
Function(String, MFGetPaymentStatusResponse)? onExecutePaymentSuccess,
Function(MFError)? onError});