MFUpdateSessionRequest class

Constructors

MFUpdateSessionRequest({required String sessionId, required String token, required String tokenType, String? securityCode})
MFUpdateSessionRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityCode String?
final
sessionId String
final
token String
final
tokenType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited